@@ -10,7 +10,21 @@ import re
 import socket
 import datetime
 from copy import deepcopy
-from django.utils.translation import ugettext_lazy as _
+
+try:
+    # django not installed
+    from django import utils
+except ImportError:
+    def _(text):
+        return text
+else:
+    try:
+        # django not configured
+        from django.core.exceptions import ImproperlyConfigured
+        from django.utils.translation import gettext_lazy as _
+    except ImproperlyConfigured:
+        def _(text):
+            return text
 
 
 class RuleNotFoundError(Exception):
@@ -46,7 +60,10 @@ class BaseRule:
         self.data = data
 
     def check(self):
-        self.check_value() if self.field_value else self.check_null()
+        if self.field_value:
+            self.check_value()
+        else:
+            self.check_null()
 
     def check_value(self):
         raise NotImplementedError()
@@ -482,6 +499,7 @@ class DatetimeAfter(BaseRule):
         return datetime.datetime.strptime(datetime_str, self.param_format_str)
 
 
+# FIX: thie required should filter the space in the given value
 class Required(BaseRule):
     name = 'required'
     message = _('{FIELD} field is required')
@@ -1036,6 +1054,52 @@ class ASCII(BaseRule):
         return False if list(seq) else True
 
 
+class PrintableASCII(BaseRule):
+    name = 'pascii'
+    message = _('this input {VALUE} is not a proper printable ASCII character string.')
+    description = _('check the give string if it is a printable ASCII string only'
+                    'contains the characters from 32 to 255')
+
+    def check_value(self):
+        no_blank = self.get_arg(0)
+        if no_blank:
+            self.status = self.check_string_no_blank()
+        else:
+            self.status = self.check_string()
+
+    def check_null(self):
+        self.status = False
+
+    def check_string(self):
+        if not self.field_value:
+            return False
+
+        seq = filter(lambda d: ord(d) > 255, ','.join(self.field_value).split(','))
+        return False if list(seq) else True
+
+    def check_string_no_blank(self):
+        code_list = [
+            *list(range(33, 126)),
+            128,
+            *list(range(130, 140)),
+            142,
+            *list(range(142, 156)),
+            *list(range(158, 159)),
+            *list(range(161, 172)),
+            *list(range(174, 255))]
+
+        field_value = self.field_value.strip()
+
+        if not field_value:
+            return False
+        else:
+            for ch in field_value:
+                if ord(ch) not in code_list:
+                    return False
+            else:
+                return True
+
+
 class Same(BaseRule):
     name = 'same'
     message = _('the input value is not same as the value of {PARAM_FIELD}')
@@ -1261,5 +1325,6 @@ default_rules = {
     Same.get_name(): Same,
     Decimal.get_name(): Decimal,
     Exist.get_name(): Exist,
-    UniqueAgainst.get_name(): UniqueAgainst
+    UniqueAgainst.get_name(): UniqueAgainst,
+    PrintableASCII.get_name(): PrintableASCII
 }
